==> openshift-model-config-6.2.0-sources.jar: io/fabric8/openshift/api/model/config/v1/HTPasswdIdentityProviderFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTPasswdIdentityProviderFluentImpl<A extends HTPasswdIdentityProviderFluent<A>> extends BaseFluent<A> implements HTPasswdIdentityProviderFluent<A>{
  public HTPasswdIdentityProviderFluentImpl() {
  }
  public HTPasswdIdentityProviderFluentImpl(HTPasswdIdentityProvider instance) {
    this.withFileData(instance.getFileData()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private SecretNameReferenceBuilder fileData;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildFileData instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretNameReference getFileData() {
    return this.fileData!=null ?this.fileData.build():null;
  }
  public SecretNameReference buildFileData() {
    return this.fileData!=null ?this.fileData.build():null;
  }
  public A withFileData(SecretNameReference fileData) {
    _visitables.get("fileData").remove(this.fileData);
    if (fileData!=null){ this.fileData= new SecretNameReferenceBuilder(fileData); _visitables.get("fileData").add(this.fileData);} else { this.fileData = null; _visitables.get("fileData").remove(this.fileData); } return (A) this;
  }
  public Boolean hasFileData() {
    return this.fileData != null;
  }
  public A withNewFileData(String name) {
    return (A)withFileData(new SecretNameReference(name));
  }
  public HTPasswdIdentityProviderFluent.FileDataNested<A> withNewFileData() {
    return new HTPasswdIdentityProviderFluentImpl.FileDataNestedImpl();
  }
  public HTPasswdIdentityProviderFluent.FileDataNested<A> withNewFileDataLike(SecretNameReference item) {
    return new HTPasswdIdentityProviderFluentImpl.FileDataNestedImpl(item);
  }
  public HTPasswdIdentityProviderFluent.FileDataNested<A> editFileData() {
    return withNewFileDataLike(getFileData());
  }
  public HTPasswdIdentityProviderFluent.FileDataNested<A> editOrNewFileData() {
    return withNewFileDataLike(getFileData() != null ? getFileData(): new SecretNameReferenceBuilder().build());
  }
  public HTPasswdIdentityProviderFluent.FileDataNested<A> editOrNewFileDataLike(SecretNameReference item) {
    return withNewFileDataLike(getFileData() != null ? getFileData(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HTPasswdIdentityProviderFluentImpl that = (HTPasswdIdentityProviderFluentImpl) o;
    if (fileData != null ? !fileData.equals(that.fileData) :that.fileData != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fileData,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (fileData != null) { sb.append("fileData:"); sb.append(fileData + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class FileDataNestedImpl<N> extends SecretNameReferenceFluentImpl<HTPasswdIdentityProviderFluent.FileDataNested<N>> implements HTPasswdIdentityProviderFluent.FileDataNested<N>,Nested<N>{
    FileDataNestedImpl(SecretNameReference item) {
      this.builder = new SecretNameReferenceBuilder(this, item);
    }
    FileDataNestedImpl() {
      this.builder = new SecretNameReferenceBuilder(this);
    }
    SecretNameReferenceBuilder builder;
    public N and() {
      return (N) HTPasswdIdentityProviderFluentImpl.this.withFileData(builder.build());
    }
    public N endFileData() {
      return and();
    }
    
  }
  
}

==> openshift-model-config-6.7.0-sources.jar: io/fabric8/openshift/api/model/config/v1/HTPasswdIdentityProviderFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTPasswdIdentityProviderFluentImpl<A extends HTPasswdIdentityProviderFluent<A>> extends BaseFluent<A> implements HTPasswdIdentityProviderFluent<A>{
  public HTPasswdIdentityProviderFluentImpl() {
  }
  public HTPasswdIdentityProviderFluentImpl(HTPasswdIdentityProvider instance) {
    if (instance != null) {
      this.withFileData(instance.getFileData());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private SecretNameReferenceBuilder fileData;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildFileData instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretNameReference getFileData() {
    return this.fileData!=null ?this.fileData.build():null;
  }
  public SecretNameReference buildFileData() {
    return this.fileData!=null ?this.fileData.build():null;
  }
  public A withFileData(SecretNameReference fileData) {
    _visitables.get("fileData").remove(this.fileData);
    if (fileData!=null){ this.fileData= new SecretNameReferenceBuilder(fileData); _visitables.get("fileData").add(this.fileData);} else { this.fileData = null; _visitables.get("fileData").remove(this.fileData); } return (A) this;
  }
  public Boolean hasFileData() {
    return this.fileData != null;
  }
  public A withNewFileData(String name) {
    return (A)withFileData(new SecretNameReference(name));
  }
  public HTPasswdIdentityProviderFluentImpl.FileDataNested<A> withNewFileData() {
    return new HTPasswdIdentityProviderFluentImpl.FileDataNestedImpl();
  }
  public HTPasswdIdentityProviderFluentImpl.FileDataNested<A> withNewFileDataLike(SecretNameReference item) {
    return new HTPasswdIdentityProviderFluentImpl.FileDataNestedImpl(item);
  }
  public HTPasswdIdentityProviderFluentImpl.FileDataNested<A> editFileData() {
    return withNewFileDataLike(getFileData());
  }
  public HTPasswdIdentityProviderFluentImpl.FileDataNested<A> editOrNewFileData() {
    return withNewFileDataLike(getFileData() != null ? getFileData(): new SecretNameReferenceBuilder().build());
  }
  public HTPasswdIdentityProviderFluentImpl.FileDataNested<A> editOrNewFileDataLike(SecretNameReference item) {
    return withNewFileDataLike(getFileData() != null ? getFileData(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTPasswdIdentityProviderFluentImpl that = (HTPasswdIdentityProviderFluentImpl) o;
    if (!java.util.Objects.equals(fileData, that.fileData)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fileData,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (fileData != null) { sb.append("fileData:"); sb.append(fileData + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class FileDataNestedImpl<N> extends SecretNameReferenceFluentImpl<HTPasswdIdentityProviderFluentImpl.FileDataNested<N>> implements HTPasswdIdentityProviderFluentImpl.FileDataNested<N>,Nested<N>{
    FileDataNestedImpl(SecretNameReference item) {
      this.builder = new SecretNameReferenceBuilder(this, item);
    }
    FileDataNestedImpl() {
      this.builder = new SecretNameReferenceBuilder(this);
    }
    SecretNameReferenceBuilder builder;
    public N and() {
      return (N) HTPasswdIdentityProviderFluentImpl.this.withFileData(builder.build());
    }
    public N endFileData() {
      return and();
    }
    
  }
  
}
